@@ -2,7 +2,7 @@ package Lingua::JA::Regular::Table;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use vars qw(@ISA @EXPORT);
 require Exporter;
@@ -13,6 +13,7 @@ use vars qw(
 	$ZENKAKU_ASCII
 	$KATAKANA
 	$HIRAGANA
+	$CHARACTER_STRICT_REGEX
 	$CHARACTER_UNDEF_REGEX
 );
 
@@ -21,6 +22,7 @@ use vars qw(
 	$ZENKAKU_ASCII
 	$KATAKANA
 	$HIRAGANA
+	$CHARACTER_STRICT_REGEX
 	$CHARACTER_UNDEF_REGEX
 );
 
@@ -37,10 +39,33 @@ $KATAKANA = qq{\xA5\xA2\xA5\xA4\xA5\xA6\xA5\xA8\xA5\xAA\xA5\xAB\xA5\xAD\xA5\xAF\
 
 $HIRAGANA = qq{\xA4\xA2\xA4\xA4\xA4\xA6\xA4\xA8\xA4\xAA\xA4\xAB\xA4\xAD\xA4\xAF\xA4\xB1\xA4\xB3\xA4\xB5\xA4\xB7\xA4\xB9\xA4\xBB\xA4\xBD\xA4\xBF\xA4\xC1\xA4\xC4\xA4\xC6\xA4\xC8\xA4\xCA\xA4\xCB\xA4\xCC\xA4\xCD\xA4\xCE\xA4\xCF\xA4\xD2\xA4\xD5\xA4\xD8\xA4\xDB\xA4\xDE\xA4\xDF\xA4\xE0\xA4\xE1\xA4\xE2\xA4\xE4\xA4\xE6\xA4\xE8\xA4\xE9\xA4\xEA\xA4\xEB\xA4\xEC\xA4\xED\xA4\xEF\xA4\xF3\xA4\xAC\xA4\xAE\xA4\xB0\xA4\xB2\xA4\xB4\xA4\xB6\xA4\xB8\xA4\xBA\xA4\xBC\xA4\xBE\xA4\xC0\xA4\xC2\xA4\xC5\xA4\xC7\xA4\xC9\xA4\xD0\xA4\xD3\xA4\xD6\xA4\xD9\xA4\xDC\xA4\xD1\xA4\xD4\xA4\xD4\xA4\xDA\xA4\xDD\xA4\xA1\xA4\xA3\xA4\xA5\xA4\xA7\xA4\xA9\xA4\xE3\xA4\xE5\xA4\xE7\xA4\xC3};
 
+
+#
+# EUC-JPʸ(¸ʸ̤ΰ衦3Хʸޤޤʤ)
+#
+$CHARACTER_STRICT_REGEX = qr{
+	(?<!\x8F)
+	(?: [\x00-\x7F]|                          # ASCII
+		\x8E[\xA1-\xDF]|                       # Ⱦѥ
+		[\xA1\xB0-\xCE\xD0-\xF3][\xA1-\xFE]|   # 1,16-46,48-83
+		\xA2[\xA1-\xAE\xBA-\xC1\xCA-\xD0\xDC-\xEA\xF2-\xF9\xFE]| # 2
+		\xA3[\xB0-\xB9\xC1-\xDA\xE1-\xFA]|     # 3
+		\xA4[\xA1-\xF3]|                       # 4
+		\xA5[\xA1-\xF6]|                       # 5
+		\xA6[\xA1-\xB8\xC1-\xD8]|              # 6
+		\xA7[\xA1-\xC1\xD1-\xF1]|              # 7
+		\xA8[\xA1-\xC0]|                       # 8
+		\xCF[\xA1-\xD3]|                       # 47
+		\xF4[\xA1-\xA6]                        # 84
+	)
+	(?= (?:[\xA1-\xFE][\xA1-\xFE])* # JIS X 0208  0ʸʾ³
+		(?:[\x00-\x7F\x8E\x8F]|\z)  # ASCII, SS2, SS3 ޤϽü
+	)
+}x;
+
+
 #
 # EUC-JP̤ʸ(¸ʸ)˥ޥåɽ
-# http://www.din.or.jp/~ohzaki/perl.htm#Character
-# http://www.din.or.jp/~ohzaki/perl.htm#JP_Match
 #
 $CHARACTER_UNDEF_REGEX = qr{
 	(?<!\x8F)
@@ -50,7 +75,7 @@ $CHARACTER_UNDEF_REGEX = qr{
 		\xA3[\xA1-\xAF\xBA-\xC0\xDB-\xE0\xFB-\xFE]|           # 3
 		\xA4[\xF4-\xFE]|                                      # 4
 		\xA5[\xF7-\xFE]|                                      # 5
-		\xA6[\x89-\xC0\xD9-\xFE]|                             # 6
+		\xA6[\xB9-\xC0\xD9-\xFE]|                             # 6
 		\xA7[\xC2-\xD0\xF2-\xFE]|                             # 7
 		\xA8[\xC1-\xFE]|                                      # 8
 		\xCF[\xD4-\xFE]|                                      # 47
@@ -62,6 +87,7 @@ $CHARACTER_UNDEF_REGEX = qr{
 	)
 }x;
 
+
 1;
 __END__
 
